@@ -18,10 +18,10 @@ package Apache2::AMFLiteDetectionFilter;
   use Apache2::RequestUtil ();
   use Apache2::SubRequest ();
   use Apache2::Log;
-  use Apache2::Filter (); 
+  use Apache2::Filter ();
   use APR::Table (); 
-  #use LWP::Simple;
-  use LWP::Simple qw($ua get);
+  use LWP::Simple ();
+  use LWP::UserAgent;
   use Apache2::Const -compile => qw(OK REDIRECT DECLINED);
   use IO::Uncompress::Unzip qw(unzip $UnzipError) ;
   use constant BUFF_LEN => 1024;
@@ -33,7 +33,7 @@ package Apache2::AMFLiteDetectionFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "4.08";
+  $VERSION= "4.09";;;
   my $CommonLib = new Apache2::AMFCommonLib ();
   my %MobileArray;#=$CommonLib->getMobileArray;
   my %MobileTabletArray;
@@ -47,17 +47,18 @@ package Apache2::AMFLiteDetectionFilter;
   my $configTouchFile;
   my $checkVersion='true';
   my $mobilenable="false";
-  my $hostNames = "downloads.sourceforge.net,master.dl.sourceforge.net,skylineservers.dl.sourceforge.net,garr.dl.sourceforge.net,jaist.dl.sourceforge.net,netassist.dl.sourceforge.net,vorboss.dl.sourceforge.net";
+  my $hostNames = "sourceforge.net";
   my @hostName = split(/,/, $hostNames);
   my $numberOfAvaiableHosts=@hostName;
   my $correctHost=0;
   my $correctHostName=$hostName[$correctHost];
-  my $hostServer="http://".$correctHostName."/project/mobilefilter/AMFRepository/";
-  my $urlmobile=$hostServer."litemobiledetection.config";
-  my $urlTablet=$hostServer."litetabletdetection.config";
-  my $urlTouch=$hostServer."litetouchdetection.config";
-  my $urlBot=$hostServer."litebotdetection.config";
+  my $hostServer="http://".$correctHostName."/projects/mobilefilter/files/AMFRepository/";
+  my $urlmobile=$hostServer."litemobiledetection.config/download";
+  my $urlTablet=$hostServer."litetabletdetection.config/download";
+  my $urlTouch=$hostServer."litetouchdetection.config/download";
+  my $urlBot=$hostServer."litebotdetection.config/download";
   my $forceBlockDownload="false";
+  my $ua=LWP::UserAgent->new;
   $CommonLib->printLog("---------------------------------------------------------------------------"); 
   $CommonLib->printLog("-------                 APACHE MOBILE FILTER V$VERSION                  -------");
   $CommonLib->printLog("------- support http://groups.google.com/group/amf-device-detection -------");
@@ -77,6 +78,7 @@ package Apache2::AMFLiteDetectionFilter;
       }
       $CommonLib->printLog("AMFSetHttpProxyPort is ".$port.$default);
       $ua->proxy('http','http://'.$ENV{AMFSetHttpProxy}.':'.$port);
+      $ua->proxy('https','https://'.$ENV{AMFSetHttpProxy}.':'.$port);
   }
   my $timeoutinsecond=5;
   my $default="";
@@ -90,39 +92,6 @@ package Apache2::AMFLiteDetectionFilter;
   if ($ENV{AMFCheckVersion}) {
 	$checkVersion=$ENV{AMFCheckVersion};
   }
-  if ($checkVersion eq 'true') {
-	$CommonLib->printLog("Check on apchemobilefilter.org if the installed AMF is the last version");  
-	my $check_version=0;
-    while ($check_version == 0 && $correctHost < $numberOfAvaiableHosts) {
-      my $url=$hostServer."amf.config";
-      $CommonLib->printLog("Try to download ".$url);
-      my $content = get ($url);
-      if ($content) {
-            $content =~ s/\n//g;
-            $check_version=$content;
-      } else {
-            $correctHost++;
-            if ($hostName[$correctHost]) {
-                  $correctHostName=$hostName[$correctHost];
-                  $hostServer="http://".$correctHostName."/project/mobilefilter/AMFRepository/";
-            }
-      }
-    }
-    if ($correctHost==$numberOfAvaiableHosts) {
-       $forceBlockDownload="true";
-		$CommonLib->printLog("It's not possible to connect to internet");
-    }
-    
-    if ($check_version > $VERSION && $check_version ne 0) {
-	       $CommonLib->printLog("---------------------------------------------------------------------------");
-	       $CommonLib->printLog("-----           There is a new version of AMF V$check_version online             ----");
-	       $CommonLib->printLog("---------------------------------------------------------------------------");
-	} else {
-		$CommonLib->printLog("AMF installed is the last version");
-	}
-  } else {
-	$CommonLib->printLog("AMFCheckVersion is false, AMF don't check the last version.");
-  }
   if ($ENV{AMFMobileHome}) {
 	  $configMobileFile="$ENV{AMFMobileHome}/amflitedetection.config";
 	  $configTabletFile="$ENV{AMFMobileHome}/amflitedetection_tablet.config";
@@ -175,8 +144,21 @@ package Apache2::AMFLiteDetectionFilter;
                           $CommonLib->printLog("For access the device to fullbrowser set the link: <url>?$mobilenable=true");
      }
 sub readMobileParamFromUrl {
-		$CommonLib->printLog("Read data from ".$correctHostName);
-		my $content = get ($urlmobile);
+		$CommonLib->printLog("Read data from ".$urlmobile);
+
+        my $req = HTTP::Request->new(HEAD => $urlmobile);
+        $req->header('Accept' => 'text/html');
+        
+        my $res = $ua->request($req);
+        
+        if ($res->is_success) {
+            $CommonLib->printLog("Redirect to:" . $res->request()->uri());
+            $urlmobile=$urlmobile;
+        } else {
+            $CommonLib->printLog("Error: " . $res->status_line);
+        }
+		my $request = $ua->get ($urlmobile);
+        my $content=$request->content;
 		if ($content) {
 			$CommonLib->printLog("Download OK");
 			$content =~ s/\n//g;
@@ -205,15 +187,29 @@ sub readMobileParamFromFile {
 			$CommonLib->printLog("Error open file:$configMobileFile");
 			ModPerl::Util::exit();
 		}
-                $content =~ s/\n//g;
+        $content =~ s/\n//g;
 		my @dummyMobileKeys = split(/,/, lc($content));
 		foreach my $dummy (@dummyMobileKeys) {
 			$MobileArray{$dummy}='mobile';
 		}
 }
 sub readTabletParamFromUrl {
-		$CommonLib->printLog("Read data for tablet detection from ".$correctHostName);
-		my $content = get ($urlTablet);
+		$CommonLib->printLog("Read data for tablet detection from ".$urlTablet);
+        my $ua = LWP::UserAgent->new;
+        my $req = HTTP::Request->new(HEAD => $urlTablet);
+        $req->header('Accept' => 'text/html');
+        
+        my $res = $ua->request($req);
+        
+        if ($res->is_success) {
+            $CommonLib->printLog("Redirect to:" . $res->request()->uri());
+            $urlTablet=$urlTablet;
+        } else {
+            $CommonLib->printLog("Error: " . $res->status_line);
+        }
+        
+		my $request = $ua->get ($urlTablet);
+        my $content=$request->content;
 		if ($content) {
 			$CommonLib->printLog("Download OK");
 			$content =~ s/\n//g;
@@ -249,8 +245,21 @@ sub readTabletParamFromFile {
 		}
 }
 sub readTouchParamFromUrl {
-		$CommonLib->printLog("Read data for touch detection from ".$correctHostName);
-		my $content = get ($urlTouch);
+		$CommonLib->printLog("Read data for touch detection from ".$urlTouch);
+        my $req = HTTP::Request->new(HEAD => $urlTouch);
+        $req->header('Accept' => 'text/html');
+        
+        my $res = $ua->request($req);
+        
+        if ($res->is_success) {
+            $CommonLib->printLog("Redirect to:" . $res->request()->uri());
+            $urlmobile=$urlmobile;
+        } else {
+            $CommonLib->printLog("Error: " . $res->status_line);
+        }
+        my $request = $ua->get ($urlTouch);
+        my $content=$request->content;
+
 		if ($content) {
 			$CommonLib->printLog("Download OK");
 			$content =~ s/\n//g;
@@ -330,6 +339,55 @@ sub cleanUA {
   $UserAgent =~ s/google favicon//g;
   return $UserAgent;
 }
+sub getOperativeSystem {
+  my ($UserAgent) = @_;
+  my $returnValue="nc";
+  my @osTypesArray = split(/,/, "android,iphone|ipad|ipod,windows phone,symbianos,blackberry,kindle");
+  my $osNumber=0;
+    foreach my $os (@osTypesArray){
+        if ($UserAgent =~ /$os/) {
+            if ($osNumber ==  0 ) {
+                $returnValue="android";
+            } elsif ($osNumber ==  1 ) {
+                $returnValue="ios";
+            } elsif ($osNumber ==  2 ) {
+                $returnValue="windows phone";
+            } elsif ($osNumber ==  3 ) {
+                $returnValue="symbian";
+            } elsif ($osNumber ==  4 ) {
+                $returnValue="kindle";
+            } 
+            return $returnValue;        
+        }
+        $osNumber++;        
+    }
+    return $returnValue;
+}
+sub getOperativeSystemVersion {
+  my ($UserAgent, $os) = (@_);
+  my $matchOS=0;
+  my $regex_param='';
+  my $return_value="nc";
+    if ($os eq 'android') {
+        $regex_param="android ([0-9]\\.[0-9](\\.[0-9])?)";
+        $matchOS=1;
+    } elsif ($os eq 'ios') {
+        $regex_param=" os ([0-9]\\_[0-9](\\_[0-9])?)";
+        $matchOS=1;
+    } elsif ($os eq 'windows phone') {
+        $regex_param="( phone| phone os) ([0-9]\\.[0-9](\\.[0-9])?)";
+        $matchOS=1;
+    } elsif ($os eq 'symbian') {
+        $regex_param="symbianos/([0-9]\\.[0-9](\\.[0-9])?)";
+        $matchOS=1;
+    } 
+    if ($matchOS == 1) {
+        ($return_value) = ($UserAgent =~ /$regex_param/);
+    }
+    
+  return $return_value;
+    
+}
 
 sub handler {
     my $f = shift;  
@@ -344,7 +402,6 @@ sub handler {
     my $id="";
     my $location="none";
     my $isTablet="false";
-    my $amf_device_istouch="false";
     my $width_toSearch;
     my $type_redirect="internal";
     my $return_value;
@@ -358,8 +415,11 @@ sub handler {
     my $var;
     my $mobile=0;
     my $amf_device_istablet='false';
+    my $amf_device_istouch='false';
     my $amf_device_ismobile='';
     my $version="";
+    my $amf_device_os='nc';
+    my $amf_device_os_version='nc';
     if ($user_agent eq "") {
 	$user_agent="no useragent found";
     }
@@ -404,6 +464,8 @@ sub handler {
 		if ($amf_device_ismobile eq 'true') {
 			$amf_device_istouch = &isTouch($user_agent);
 			$amf_device_istablet=&isTablet($user_agent);
+            $amf_device_os=&getOperativeSystem($user_agent);
+            $amf_device_os_version=&getOperativeSystemVersion($user_agent,$amf_device_os);            
 		}
 		if ($cookiecachesystem eq "true") {
 			$f->err_headers_out->set('Set-Cookie' => "amfID=$id; path=/;");	
@@ -420,6 +482,9 @@ sub handler {
 	$f->subprocess_env("AMF_DEVICE_IS_MOBILE" => $amf_device_ismobile);
 	$f->subprocess_env("AMF_DEVICE_IS_TABLET" => $amf_device_istablet);
 	$f->subprocess_env("AMF_DEVICE_IS_TOUCH" => $amf_device_istouch);
+	$f->subprocess_env("AMF_DEVICE_MOBILE_OS" => $amf_device_os);
+	$f->subprocess_env("AMF_DEVICE_MOBILE_OS_VERSION" => $amf_device_os_version);
+    
 	$f->subprocess_env("AMF_VER" => $VERSION);
 	$f->headers_out->set("AMF-Ver"=> $VERSION);
 	if ($x_operamini_ua) {
